@@ -39,6 +39,7 @@ from typing import Type, TypeVar
 
 from dataclass_utils.type_checker import check_root as check_type
 from dataclass_utils.type_checker import runtime_typecheck_inner
+from dataclass_utils.into_dataclass import into_dataclass
 
 T = TypeVar("T")
 
@@ -47,4 +48,4 @@ def runtime_typecheck(ty: Type[T]) -> Type[T]:
     return runtime_typecheck_inner(ty)  # type: ignore
 
 
-__all__ = ["runtime_typecheck", "check_type"]
+__all__ = ["runtime_typecheck", "check_type", "into_dataclass"]
